-- Copyright (c) 2012 Cloudera, Inc. All rights reserved.
--
-- Version 7 of the CMON schema.
--
-- With this version we introduced support for Oracle. Oracle has a limit
-- of 30 characters for table names and columns, and we are above that
-- limit in few cases. So this script alters those tables to bring the
-- names within limit. Unfortunately, the tables that come under this case are
-- tables that we partition, and name of these partition tables are dynamic,
-- as they are generated at runtime. We need to change those names too to
-- make sure existing deployed instances continue to function correctly.

UPDATE CMON_SCHEMA_VERSION SET VERSION=7;

-- Update all records in CMON_PARTITION_INFO, replacing each occurance of
-- CMON_LONG_LIVED_DATA_POINTS with CMON_LL_DP and
-- CMON_LONG_LIVED_DATA_POINTS_HOURLY with CMON_LL_DP_HR
UPDATE CMON_PARTITION_INFO SET NAME = CONCAT("CMON_LL_DP_HR", SUBSTR(NAME, LENGTH("CMON_LONG_LIVED_DATA_POINTS_HOURLY_"))) WHERE NAME LIKE 'CMON_LONG_LIVED_DATA_POINTS_HOURLY%';
UPDATE CMON_PARTITION_INFO SET BASE_TABLE = CONCAT("CMON_LL_DP_HR", SUBSTR(BASE_TABLE, LENGTH("CMON_LONG_LIVED_DATA_POINTS_HOURLY_"))) WHERE BASE_TABLE LIKE 'CMON_LONG_LIVED_DATA_POINTS_HOURLY%';
UPDATE CMON_PARTITION_INFO SET NAME = CONCAT("CMON_LL_DP", SUBSTR(NAME, LENGTH("CMON_LONG_LIVED_DATA_POINTS_"))) WHERE NAME LIKE 'CMON_LONG_LIVED_DATA_POINTS%';
UPDATE CMON_PARTITION_INFO SET BASE_TABLE = CONCAT("CMON_LL_DP", SUBSTR(BASE_TABLE, LENGTH("CMON_LONG_LIVED_DATA_POINTS_"))) WHERE BASE_TABLE LIKE 'CMON_LONG_LIVED_DATA_POINTS%';

-- Tables used for partition have YYYY_MM_DD suffix'ed to them, so we need to
-- rename them too so that overall name doesn't exceed 30 chars.
com.cloudera.cmon.firehose.db.ShortenMySQLTableNames

-- Rename all the tables having more than 30 characters to bring them within
-- limit. Then to maintain consistent naming scheme, we rename all other tables
-- that have same phrase.
RENAME TABLE CMON_ACTIVITY_LAST_METRIC_VALUE TO CMON_ACTIVITY_LAST_METRIC_VAL;
RENAME TABLE CMON_ATTEMPT_LAST_METRIC_VALUE TO CMON_ATTEMPT_LAST_METRIC_VAL;
RENAME TABLE CMON_LONG_LIVED_TIME_SERIES_ATTRIBUTE TO CMON_LL_TIME_SERIES_ATTRIBUTE;
RENAME TABLE CMON_LONG_LIVED_TIME_SERIES_ID TO CMON_LL_TIME_SERIES_ID;
RENAME TABLE CMON_ACTIVITY_DATA_POINTS TO CMON_ACTIVITY_DP;

--
-- Add foreign key constraint to CMON_LONG_LIVED_DATA_POINTS that inadvertently
-- got dropped in 00006_cmon_schmea.mysql.ddl file.
-- This foreign key only exists on the initial partitions. Other partitions
-- don't copy it over (see CreatePartitionTable.java)
-- OPSAPS-10606 has been opened to address this.
--
ALTER TABLE CMON_LL_DP ADD CONSTRAINT FK_LL_RAW_SERIES_ID foreign key (SERIES_ID) references CMON_LL_TIME_SERIES_ID (ID);
